@@ -11,10 +11,8 @@ import dns.rdatatype
 import dns.tsig
 import dns.tsigkeyring
 import dns.update
-import zope.interface
 
 from certbot import errors
-from certbot import interfaces
 from certbot.plugins import dns_common
 from certbot.plugins.dns_common import CredentialsConfiguration
 
@@ -22,8 +20,7 @@ logger = logging.getLogger(__name__)
 
 DEFAULT_NETWORK_TIMEOUT = 45
 
-@zope.interface.implementer(interfaces.IAuthenticator)
-@zope.interface.provider(interfaces.IPluginFactory)
+
 class Authenticator(dns_common.DNSAuthenticator):
     """DNS Authenticator using RFC 2136 Dynamic Updates
 
